@@ -293,6 +293,9 @@ void BaseQNAcceleration::performAcceleration(
     if (not(_filter == Acceleration::QR2FILTER || _filter == Acceleration::QR3FILTER)) { // for QR2 and QR3 filter, there is no need to do this twice
       _qrV.reset(_matrixV, getLSSystemRows());
     }
+    if (_filter == Acceleration::QR3FILTER) { // QR3 filter needs to recompute QR3 filter
+      _qrV.requireQR3Fallback();
+    }
     _preconditioner->newQRfulfilled();
   }
 
