@@ -154,7 +154,7 @@ void RadialBasisFctMapping<SOLVER_T, Args...>::computeMapping()
     }
 
     // Forwarding the tuples here requires some template magic I don't want to implement
-    if constexpr (std::tuple_size_v < std::tuple < Args... >>> 0) {
+    if constexpr (sizeof...(Args) > 0) {
       _rbfSolver = std::make_unique<SOLVER_T>(this->_basisFunction, globalInMesh, boost::irange<Eigen::Index>(0, globalInMesh.nVertices()),
                                               globalOutMesh, boost::irange<Eigen::Index>(0, globalOutMesh.nVertices()), this->_deadAxis, _polynomial, std::get<0>(optionalArgs));
     } else {
@@ -174,10 +174,10 @@ void RadialBasisFctMapping<SOLVER_T, Args...>::clear()
   this->_hasComputedMapping = false;
 }
 
-template <typename SOLVER_T, typename... Args>
-std::string RadialBasisFctMapping<SOLVER_T, Args...>::getName() const
+template <typename... Args>
+static std::string getNameWithArgs(const std::tuple<Args...> &optionalArgs)
 {
-  if constexpr (std::tuple_size_v < std::tuple < Args... >>> 0) {
+  if constexpr (sizeof...(Args) > 0) {
     auto        param = std::get<0>(optionalArgs);
     std::string exec  = param.executor;
     if (param.solver == "qr-solver") {
@@ -190,6 +190,12 @@ std::string RadialBasisFctMapping<SOLVER_T, Args...>::getName() const
   }
 }
 
+template <typename SOLVER_T, typename... Args>
+std::string RadialBasisFctMapping<SOLVER_T, Args...>::getName() const
+{
+  return getNameWithArgs(optionalArgs);
+}
+
 template <typename SOLVER_T, typename... Args>
 void RadialBasisFctMapping<SOLVER_T, Args...>::mapConservative(const time::Sample &inData, Eigen::VectorXd &outData)
 {
